export * from '@primevue/icons/angledoubledown';
export { default as AngleDoubleDownIcon } from '@primevue/icons/angledoubledown';
export * from '@primevue/icons/angledoubleleft';
export { default as AngleDoubleLeftIcon } from '@primevue/icons/angledoubleleft';
export * from '@primevue/icons/angledoubleright';
export { default as AngleDoubleRightIcon } from '@primevue/icons/angledoubleright';
export * from '@primevue/icons/angledoubleup';
export { default as AngleDoubleUpIcon } from '@primevue/icons/angledoubleup';
export * from '@primevue/icons/angledown';
export { default as AngleDownIcon } from '@primevue/icons/angledown';
export * from '@primevue/icons/angleleft';
export { default as AngleLeftIcon } from '@primevue/icons/angleleft';
export * from '@primevue/icons/angleright';
export { default as AngleRightIcon } from '@primevue/icons/angleright';
export * from '@primevue/icons/angleup';
export { default as AngleUpIcon } from '@primevue/icons/angleup';
export * from '@primevue/icons/arrowdown';
export { default as ArrowDownIcon } from '@primevue/icons/arrowdown';
export * from '@primevue/icons/arrowup';
export { default as ArrowUpIcon } from '@primevue/icons/arrowup';
export * from '@primevue/icons/ban';
export { default as BanIcon } from '@primevue/icons/ban';
export * from '@primevue/icons/bars';
export { default as BarsIcon } from '@primevue/icons/bars';
export * from '@primevue/icons/baseicon';
export { default as BaseIcon } from '@primevue/icons/baseicon';
export * from '@primevue/icons/baseicon/style';
export { default as BaseIconStyle } from '@primevue/icons/baseicon/style';
export * from '@primevue/icons/blank';
export { default as BlankIcon } from '@primevue/icons/blank';
export * from '@primevue/icons/calendar';
export { default as CalendarIcon } from '@primevue/icons/calendar';
export * from '@primevue/icons/check';
export { default as CheckIcon } from '@primevue/icons/check';
export * from '@primevue/icons/chevrondown';
export { default as ChevronDownIcon } from '@primevue/icons/chevrondown';
export * from '@primevue/icons/chevronleft';
export { default as ChevronLeftIcon } from '@primevue/icons/chevronleft';
export * from '@primevue/icons/chevronright';
export { default as ChevronRightIcon } from '@primevue/icons/chevronright';
export * from '@primevue/icons/chevronup';
export { default as ChevronUpIcon } from '@primevue/icons/chevronup';
export * from '@primevue/icons/exclamationtriangle';
export { default as ExclamationTriangleIcon } from '@primevue/icons/exclamationtriangle';
export * from '@primevue/icons/eye';
export { default as EyeIcon } from '@primevue/icons/eye';
export * from '@primevue/icons/eyeslash';
export { default as EyeSlashIcon } from '@primevue/icons/eyeslash';
export * from '@primevue/icons/filter';
export { default as FilterIcon } from '@primevue/icons/filter';
export * from '@primevue/icons/filterslash';
export { default as FilterSlashIcon } from '@primevue/icons/filterslash';
export * from '@primevue/icons/infocircle';
export { default as InfoCircleIcon } from '@primevue/icons/infocircle';
export * from '@primevue/icons/minus';
export { default as MinusIcon } from '@primevue/icons/minus';
export * from '@primevue/icons/pencil';
export { default as PencilIcon } from '@primevue/icons/pencil';
export * from '@primevue/icons/plus';
export { default as PlusIcon } from '@primevue/icons/plus';
export * from '@primevue/icons/refresh';
export { default as RefreshIcon } from '@primevue/icons/refresh';
export * from '@primevue/icons/search';
export { default as SearchIcon } from '@primevue/icons/search';
export * from '@primevue/icons/searchminus';
export { default as SearchMinusIcon } from '@primevue/icons/searchminus';
export * from '@primevue/icons/searchplus';
export { default as SearchPlusIcon } from '@primevue/icons/searchplus';
export * from '@primevue/icons/sortalt';
export { default as SortAltIcon } from '@primevue/icons/sortalt';
export * from '@primevue/icons/sortamountdown';
export { default as SortAmountDownIcon } from '@primevue/icons/sortamountdown';
export * from '@primevue/icons/sortamountupalt';
export { default as SortAmountUpAltIcon } from '@primevue/icons/sortamountupalt';
export * from '@primevue/icons/spinner';
export { default as SpinnerIcon } from '@primevue/icons/spinner';
export * from '@primevue/icons/star';
export { default as StarIcon } from '@primevue/icons/star';
export * from '@primevue/icons/starfill';
export { default as StarFillIcon } from '@primevue/icons/starfill';
export * from '@primevue/icons/thlarge';
export { default as ThLargeIcon } from '@primevue/icons/thlarge';
export * from '@primevue/icons/times';
export { default as TimesIcon } from '@primevue/icons/times';
export * from '@primevue/icons/timescircle';
export { default as TimesCircleIcon } from '@primevue/icons/timescircle';
export * from '@primevue/icons/trash';
export { default as TrashIcon } from '@primevue/icons/trash';
export * from '@primevue/icons/undo';
export { default as UndoIcon } from '@primevue/icons/undo';
export * from '@primevue/icons/upload';
export { default as UploadIcon } from '@primevue/icons/upload';
export * from '@primevue/icons/windowmaximize';
export { default as WindowMaximizeIcon } from '@primevue/icons/windowmaximize';
export * from '@primevue/icons/windowminimize';
export { default as WindowMinimizeIcon } from '@primevue/icons/windowminimize';
//# sourceMappingURL=index.mjs.map
